"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var core_1 = require("@angular/core");
var index_1 = require("../index");
var ApplicationSettingsService = (function () {
    function ApplicationSettingsService(baasicApp) {
        this.baasicApp = baasicApp;
    }
    /**
     * Returns a promise that is resolved once the get action has been performed. Success response returns the application settings resource.
     * @method
     * @param options Query resource options object.
     * @example ApplicationSettingsService.get()
                    .then(function (data) {
                        // perform success action here
                    },
                     function (response, status, headers, config) {
                        // perform error handling here
                    });
     **/
    ApplicationSettingsService.prototype.get = function (options) {
        return this.baasicApp.applicationSettingModule.get(options);
    };
    /**
     * Returns a promise that is resolved once the update application settings action has been performed. This action updates the application setting resource. This route uses HAL enabled objects to obtain routes and therefore it doesn't use `baasicApplicationSettingsRouteDefinition` route template. Here is an example of how a route can be obtained from HAL enabled objects:
     * ```
     * let params = modelMapper.removeParams(appSettings);
     * let uri = params['model'].links('put').href;
     * ```
     * @method
     * @param data An application object used to update application settings of the specified application resource.
     * @example // appSettings is a resource previously fetched using get action.
                    appSettings.allowAnyOrigin = true;
                    ApplicationSettingsService.update(appSettings)
                        .then(function (data) {
                            // perform success action here
                        },
                         function (response, status, headers, config) {
                            // perform error handling here
                        });
     **/
    ApplicationSettingsService.prototype.update = function (data) {
        return this.baasicApp.applicationSettingModule.update(data);
    };
    return ApplicationSettingsService;
}());
ApplicationSettingsService = tslib_1.__decorate([
    core_1.Injectable(),
    tslib_1.__metadata("design:paramtypes", [index_1.BaasicAppService])
], ApplicationSettingsService);
exports.ApplicationSettingsService = ApplicationSettingsService;
